@@ -1352,7 +1352,7 @@ def load_fform(fform_filename):
     """Creat instance of fFormContainer from a fform_filename.
 
     ``fform_filename`` s are generated using the utilities provided
-    in the :class:`~shgpy.fformgen` package. Those utilities output
+    in the :mod:`~shgpy.fformgen` module. Those utilities output
     a pickled fFormContainer-like object which can be loaded into
     a true fFormContainer instance using this function.
 
@@ -1361,6 +1361,10 @@ def load_fform(fform_filename):
     fform_filename : str or file object
 
     """
-    with open(fform_filename, 'rb') as f:
-        fform_dict = pickle.load(f)
-    return fFormContainer(fform_dict)
+    with open(fform_filename, 'rb') as fh:
+        str_fform_dict = pickle.load(fh)
+    _fform_dict = {
+        k:np.array([sp.sympify(s) for s in v])
+        for k,v in str_fform_dict.items()
+    }
+    return fFormContainer(_fform_dict)
